%define anolis_release 1

%bcond_without pkgconfig_compat

%if %{with pkgconfig_compat}
%global pkgconfig_ver 0.29.1
%global pkgconfig_verrel %{pkgconfig_ver}-3
%global pkgconfig_evr 1:%{pkgconfig_verrel}
%endif

%bcond_with tests

# Search path for pc files for pkgconf
%global pkgconf_libdirs %{_libdir}/pkgconfig:%{_datadir}/pkgconfig

# libpkgconf soversion major version
%global libsomajor 4

Name:           pkgconf
Version:        1.9.5
Release:        %{anolis_release}%{?dist}
Summary:        Package compiler and linker metadata toolkit

License:        ISC
URL:            http://pkgconf.org/
Source0:        https://distfiles.dereferenced.org/%{name}/%{name}-%{version}.tar.xz

Source1:        platform-pkg-config.in
Source2:        pkg-config.in

BuildRequires:  gcc make autoconf automake libtool

%if %{with tests}
BuildRequires:  kyua atf-tests
%endif

Requires:       lib%{name} = %{version}-%{release}
Provides:       pkgconfig(pkgconf) = %{version}

%description
pkgconf is a program which helps to configure compiler and linker flags
for development frameworks. It is similar to pkg-config from freedesktop.org
and handles .pc files in a similar manner as pkg-config.

%package -n lib%{name}
Summary:        Backend library for %{name}

%description -n lib%{name}
This package provides libraries for applications to use the functionality
of %{name}.

%package -n lib%{name}-devel
Summary:        Development files for lib%{name}
Requires:       lib%{name} = %{version}-%{release}

%description -n lib%{name}-devel
This package provides files necessary for developing applications
to use functionality provided by %{name}.

%if %{with pkgconfig_compat}
%package m4
Summary:        m4 macros for pkgconf
License:        GPLv2+ with exceptions
BuildArch:      noarch
Conflicts:      pkgconfig < %{pkgconfig_evr}
Obsoletes:      pkgconfig < %{pkgconfig_evr}

%description m4
This package includes m4 macros used to support PKG_CHECK_MODULES
when using pkgconf with autotools.

%package pkg-config
Summary:        %{name} shim to provide /usr/bin/pkg-config
Conflicts:      pkgconfig < %{pkgconfig_evr}
Obsoletes:      pkgconfig < %{pkgconfig_evr}
Provides:       pkgconfig = %{pkgconfig_evr}
Provides:       pkgconfig(pkg-config) = %{version}
Provides:       pkg-config = %{pkgconfig_verrel}
Requires:       %{name} = %{version}-%{release}
Requires:       %{name}-m4 = %{version}-%{release}

%description pkg-config
This package provides the shim links for pkgconf to be automatically
used in place of pkgconfig. This ensures that pkgconf is used as
the system provider of pkg-config.

%endif

%package -n bomtool
Summary:        Simple SBOM generator using pc(5) files
Requires:       lib%{name}%{?_isa} = %{version}-%{release}

%description -n bomtool
bomtool is a program which helps generate a Software Bill of Materials
manifest using data from installed .pc files.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{EVR}
BuildArch:      noarch

%description  doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%autosetup -p1

%build
autoreconf -fiv
%configure --disable-static \
           --with-pkg-config-dir=%{pkgconf_libdirs} \
           --with-system-includedir=%{_includedir} \
           --with-system-libdir=%{_libdir}

%make_build V=1


%check
%if %{with tests}
make check || :
%endif


%install
%make_install

find %{buildroot} -name '*.la' -print -delete

mkdir -p %{buildroot}%{_sysconfdir}/pkgconfig/personality.d
mkdir -p %{buildroot}%{_datadir}/pkgconfig/personality.d

mkdir -p %{buildroot}%{_rpmmacrodir}/

cat > %{buildroot}%{_rpmmacrodir}/macros.pkgconf <<EOM
%%pkgconfig_personalitydir %{_datadir}/pkgconfig/personality.d
EOM

%if %{with pkgconfig_compat}
install -pm 0755 %{SOURCE1} %{buildroot}%{_bindir}/%{_target_platform}-pkg-config

sed -e "s|@TARGET_PLATFORM@|%{_target_platform}|" \
    -e "s|@PKGCONF_LIBDIRS_LOCAL@|/usr/local/%{_lib}/pkgconfig:/usr/local/share/pkgconfig:%{pkgconf_libdirs}|" \
    -e "s|@PKGCONF_LIBDIRS@|%{pkgconf_libdirs}|" \
    -e "s|@PKGCONF_SYSLIBDIR@|%{_libdir}|" \
    -e "s|@PKGCONF_SYSINCDIR@|%{_includedir}|" \
    -i %{buildroot}%{_bindir}/%{_target_platform}-pkg-config

install -pm 0755 %{SOURCE2} %{buildroot}%{_bindir}/pkg-config

sed -e "s|@PKGCONF_BINDIR@|%{_bindir}|" \
    -i %{buildroot}%{_bindir}/pkg-config

echo ".so man1/pkgconf.1" > %{buildroot}%{_mandir}/man1/pkg-config.1

mkdir -p %{buildroot}%{_libdir}/pkgconfig
mkdir -p %{buildroot}%{_datadir}/pkgconfig
%endif

%if ! %{with pkgconfig_compat}
rm -rf %{buildroot}%{_datadir}/aclocal
%endif

%generate_compatibility_deps

rm %{buildroot}%{_datadir}/doc/%{name}/{AUTHORS,README.md}

%ldconfig_scriptlets -n lib%{name}

%files
%license COPYING
%{_bindir}/%{name}
%{abidir}/%{name}-option.list
%{_mandir}/man1/%{name}.1*
%{_mandir}/man5/pc.5*
%{_mandir}/man5/%{name}-personality.5*
%{_rpmmacrodir}/macros.pkgconf
%dir %{_sysconfdir}/pkgconfig
%dir %{_sysconfdir}/pkgconfig/personality.d
%dir %{_datadir}/pkgconfig/personality.d

%files -n lib%{name}
%license COPYING
%dir %{abidir}
%{_libdir}/lib%{name}*.so.%{libsomajor}{,.*}
%{abidir}/lib%{name}*.dump

%files -n lib%{name}-devel
%{_libdir}/lib%{name}*.so
%{_includedir}/%{name}/
%{_libdir}/pkgconfig/lib%{name}.pc

%if %{with pkgconfig_compat}
%files m4
%{_datadir}/aclocal/pkg.m4
%{_mandir}/man7/pkg.m4.7*

%files pkg-config
%{_bindir}/pkg-config
%{_bindir}/%{_target_platform}-pkg-config
%{abidir}/pkg-config-option.list
%{abidir}/%{_target_platform}-pkg-config-option.list
%{_mandir}/man1/pkg-config.1*
%dir %{_libdir}/pkgconfig
%dir %{_datadir}/pkgconfig
%endif

%files -n bomtool
%{_bindir}/bomtool
%{abidir}/bomtool-option.list

%files doc
%doc AUTHORS README.md NEWS

%changelog
* Sun Oct 08 2023 mgb01105731 <mgb01105731@alibaba-inc.com> - 1.9.5-1
- update to 1.9.5

* Wed Apr 12 2023 yuanhui <yuanhui@linux.alibaba.com> - 1.8.1-4
- Fix the bug of unresolved macro

* Tue Apr 11 2023 yuanhui <yuanhui@linux.alibaba.com> - 1.8.1-3
- Optimize the spec file

* Mon Mar 27 2023 mgb01105731 <mgb01105731@alibaba-inc.com> - 1.8.1-2
- Del Specific Fields

* Mon Jan 23 2023 Funda Wang <fundawang@yeah.net> - 1.8.1-1
- New version 1.8.1

* Mon Oct 24 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 1.8.0-3
- optimise spec file

* Thu Sep 29 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 1.8.0-2
- add doc package

* Mon Feb 28 2022 CHunmei Xu <xuchunmei@linux.alibaba.com> - 1.8.0-1
- upstream version 1.8.0
